@@ -615,6 +615,36 @@ dispatcher[unmangle(f.__name__)] = f
 
 #----------------------------#
 
+def move_pattern(moosic, arglist, opts):
+    '''move-pattern <regex> <index> - Moves all items that match the given regex
+    to a new position in the song queue.'''
+    pattern, destination = arglist
+    try:
+        if not (destination[0].isdigit() or destination[0] == '-'):
+            destination = destination[1:]
+        if not (destination[-1].isdigit() or destination[-1] == '-'):
+            destination = destination[:-1]
+        destination = int(destination)
+    except ValueError, e:
+        print >>err, 'Error:', e 
+        print >>err, 'An integer is required as the final argument.'
+        return 2
+    all_items = [i.data for i in moosic.list()]
+    if opts['ignore-case']:
+        pattern += '(?i)'
+    items_to_move = grep(pattern, all_items)
+    head = antigrep(pattern, all_items[:destination])
+    tail = antigrep(pattern, all_items[destination:])
+    all_items = head + items_to_move + tail
+    moosic.replace([xmlrpclib.Binary(i) for i in all_items])
+
+f = move_pattern
+f.category = 'rearrange'
+f.num_args = 'two'
+dispatcher[unmangle(f.__name__)] = f
+
+#----------------------------#
+
 def swap(moosic, arglist, opts):
     '''swap <range> <range> - Causes two segments of the queue to trade places.'''
     r1 = parse_range(arglist[0], 0, None)
@@ -875,6 +905,12 @@ def list_(moosic, arglist, opts):
         start, end = parse_range(arglist[0], 0, None)
     else:
         start, end = 0, None
+    if opts['current-in-list']:
+        if arglist:
+            print >>sys.stderr, wrap("Warning: the -C option has no effect "
+                    "if an argument is given.")
+        else:
+            print "[*]", moosic.current().data
     if end is None:
         d = moosic.indexed_list((start,))
     else:
@@ -904,6 +940,12 @@ def plainlist(moosic, arglist, opts):
     else:
         start, end = 0, None
     try:
+        if opts['current-in-list']:
+            if arglist:
+                print >>sys.stderr, wrap("Warning: the -C option has no effect "
+                        "if an argument is given.")
+            else:
+                print moosic.current().data
         if end is None:
             print '\n'.join([i.data for i in moosic.list((start,))])
         else:
