@@ -85,6 +85,8 @@ def main(argv):
                                 already running.
         -U, --allow-unplayable  Allow songs that the server doesn't know how to
                                 play to be added into the song queue.
+        -C, --current-in-list   Show the currently playing song in the "list"
+                                and "plainlist" commands.
         -S, --showcommands      Print the list of possible commands and exit.
         -h, --help              Print this help text and exit.
         -v, --version           Print version information and exit.
@@ -110,6 +112,7 @@ def main(argv):
                          't:':'tcp=',
                          'N':'no-startserver',
                          'U':'allow-unplayable',
+                         'C':'current-in-list',
                          'S':'showcommands',
                          'h':'help',
                          'v':'version', }
@@ -168,6 +171,8 @@ def main(argv):
                 opts['start moosicd'] = False
             if option == '-U' or option == '--allow-unplayable':
                 opts['no-unplayables'] = False
+            if option == '-C' or option == '--current-in-list':
+                opts['current-in-list'] = True
             if option == '-S' or option == '--showcommands':
                 print COMMANDS
                 sys.exit(0)
@@ -191,7 +196,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."""
             'music-dir':os.path.join(home, 'music', ''), 'auto-find':False,
             'auto-grep':False, 'start moosicd':True, 'ignore-case':False,
             'sort':False, 'rc-filename':os.path.join(home, '.moosicrc'),
-            'no-unplayables':True}
+            'no-unplayables':True, 'current-in-list':False}
     # Gather options specified before the command.
     arglist, opts = process_options(argv[1:], opts)
     # Pluck the command out of the argument list.
