@@ -465,7 +465,7 @@ def main(argv):
        #    data.log(Log.DEBUG, traceback.format_stack(stackframe)) #
         if signum:
             data.log(Log.NOTICE, "Killed by signal %d (PID: %d)." %
-                                 (signum, os.getpid))
+                                 (signum, os.getpid()))
         sys.exit()
     signal.signal(signal.SIGINT, quit)
     signal.signal(signal.SIGTERM, quit)
