@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 API_MAJOR_VERSION = 1
-API_MINOR_VERSION = 7
+API_MINOR_VERSION = 8
 
 # Import from the standard library.
 import xmlrpclib, time, os, signal, random, re, errno, operator
@@ -29,39 +29,14 @@ except NameError: True = 1
 try: False
 except NameError: False = 0
 
-def is_overlapping(A, B, n):
-    '''Tests whether the slices described by two ranges overlap each other.
-    
-    Arguments "A" and "B": pairs (2-tuples) of integers, each of which
-    represents a range within a sequence.  The first of each pair is the index
-    of the first item included in the range, and the second of each pair is the
-    index of the item that terminates the range (but is not included in the
-    range).
-    
-    Argument "n": an integer that represents the length of the sequence in which
-    these ranges will be applied.
-    
-    Returns: True if the ranges overlap, otherwise False.
-    '''
-    # Handle negative numbers as range indices.
-    if A[0] < 0: A[0] = n - A[0]
-    if A[1] < 0: A[1] = n - A[1]
-    if B[0] < 0: B[0] = n - B[0]
-    if B[1] < 0: B[1] = n - B[1]
-    # Any one of these tests indicate overlap.
-    if A[0] <= B[0] < A[1]: return True
-    if A[0] <= B[1] < A[1]: return True
-    if B[0] <= A[0] < B[1]: return True
-    if B[0] <= A[1] < B[1]: return True
-    return False
-
 # Import from my own modules.
 import xmlrpc_registry
 from xmlrpc_registry import INT, BOOLEAN, DOUBLE, STRING, ARRAY, STRUCT, BASE64
 import moosic.utilities
-from moosic.utilities import grep, antigrep, splitpath
+from moosic.utilities import grep, antigrep, splitpath, is_overlapping
 import moosic.server.support
 from moosic.server.support import data, Log, split_range
+from moosic import VERSION
 
 moosicd_methods = xmlrpc_registry.Registry()
 
@@ -897,7 +872,7 @@ def swap(range_A, range_B):
         if B[1] < 0:   B[1] = n - B[1]
         # Forbid overlapping ranges.
         if is_overlapping(A, B, len(data.song_queue)):
-            raise ValueError("Overlapping ranges may not be swapped")
+            raise ValueError("Overlapping ranges may not be swapped: %s %s" % (A, B))
         # Make sure range A is closer to the head of the queue than range B.
         if A > B:
             A, B = B, A
@@ -1009,8 +984,8 @@ def history(limit=0):
     '''Returns a list of the items that were recently played.
  
     Arguments: If a positive integer argument is given, then no more than that
-        number of entries will be printed.  If a number is not specified, or if
-        zero is given, then the entire history is printed.  The result is
+        number of entries will be returned.  If a number is not specified, or if
+        zero is given, then the entire history is returned.  The result is
         undefined if a negative integer argument is given (but does not raise an
         exception).
     Return value: An array of triples, each representing a song that was played
@@ -1113,27 +1088,6 @@ length = queue_length
 moosicd_methods.register(queue_length, [[INT]], "length")
 
 
-#def current_time():
-#    '''Returns the amount of time that the current song has been playing.
-# 
-#    Arguments: None.
-#    Return value: The number of seconds that the current song has been playing.
-#    '''
-#    if not data.current_song:
-#        return 0
-#    # Sanity check.
-#    time_list_is_even = not len(data.start_stop_times) % 2
-#    if (data.paused and not time_list_is_even) \
-#            or (not data.paused and time_list_is_even):
-#        raise Exception('Internal server error.')
-#    # Sum up the times of the "pause" and "unpause" events.
-#    if data.paused:
-#        return reduce(operator.add, data.start_stop_times)
-#    else:
-#        return reduce(operator.add, data.start_stop_times + [time.time()])
-#moosicd_methods.register(current_time, [[DOUBLE]])
-
-
 def current_time():
     # This alternate version works in constant time, rather than depending on
     # the length of an arbitrarily long list of play/pause events.
@@ -1157,7 +1111,7 @@ def version():
     Arguments: None.
     Return value: The version string for the Moosic server.
     '''
-    return moosic.server.VERSION
+    return VERSION
 moosicd_methods.register(version, [[STRING]])
 
 
@@ -1295,5 +1249,3 @@ moosicd_methods.register(lambda:1, [[BOOLEAN]], "__nonzero__")
 #        code = str(code.data)
 #    return Binary('%s' % eval(code))
 #moosicd_methods.register(debug, [[BASE64, BASE64]])
-
-
