@@ -393,6 +393,7 @@ class UnixMoosicRequestHandler(SimpleXMLRPCServer.SimpleXMLRPCRequestHandler):
 class TcpMoosicRequestHandler(SimpleXMLRPCServer.SimpleXMLRPCRequestHandler):
     """An adaptation of SimpleXMLRPCRequestHandler for use with TCP sockets.
     """
+    # Actually, no adaptation needs to be done.
     pass
 
 
@@ -404,12 +405,10 @@ class UnixMoosicServer(SocketServer.ThreadingMixIn,
     # Portability note: By default, Unix domain sockets are used to implement
     # interprocess communication between the client and the server. This prevents
     # this program from working on (most, if not all) non-Unix systems.
-    def __init__(self, addr, logRequests=0):
-        self.funcs = {}    
-        self.logRequests = logRequests
-        self.instance = None
-        SocketServer.UnixStreamServer. \
-                __init__(self, addr, UnixMoosicRequestHandler)
+    def __init__(self, addr, logRequests=False):
+        SimpleXMLRPCServer.SimpleXMLRPCServer.__init__(self, addr,
+                requestHandler=UnixMoosicRequestHandler,
+                logRequests=logRequests)
 
     def process_request(self, request, client_address):
         """Start a new thread to process the request.
@@ -453,11 +452,10 @@ class TcpMoosicServer(SocketServer.ThreadingMixIn,
                       SimpleXMLRPCServer.SimpleXMLRPCServer):
     """A server that responds to Moosic requests via TCP/IP.
     """
-    def __init__(self, addr, logRequests=0):
-        self.funcs = {}    
-        self.logRequests = logRequests
-        self.instance = None
-        SocketServer.TCPServer.__init__(self, addr, TcpMoosicRequestHandler)
+    def __init__(self, addr, logRequests=False):
+        SimpleXMLRPCServer.SimpleXMLRPCServer.__init__(self, addr,
+                requestHandler=TcpMoosicRequestHandler,
+                logRequests=logRequests)
 
     def process_request(self, request, client_address):
         """Start a new thread to process the request.
